==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/SynchronizationSchedule.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.Duration;
import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.enums.SynchronizationScheduleState;

@JsonPropertyOrder({
    "@odata.type", 
    "expiration", 
    "interval", 
    "state"})
@JsonInclude(Include.NON_NULL)
public class SynchronizationSchedule implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("expiration")
    protected OffsetDateTime expiration;

    @JsonProperty("interval")
    protected Duration interval;

    @JsonProperty("state")
    protected SynchronizationScheduleState state;

    protected SynchronizationSchedule() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.synchronizationSchedule";
    }

    @Property(name="expiration")
    @JsonIgnore
    public Optional<OffsetDateTime> getExpiration() {
        return Optional.ofNullable(expiration);
    }

    public SynchronizationSchedule withExpiration(OffsetDateTime expiration) {
        SynchronizationSchedule _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSchedule");
        _x.expiration = expiration;
        return _x;
    }

    @Property(name="interval")
    @JsonIgnore
    public Optional<Duration> getInterval() {
        return Optional.ofNullable(interval);
    }

    public SynchronizationSchedule withInterval(Duration interval) {
        SynchronizationSchedule _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSchedule");
        _x.interval = interval;
        return _x;
    }

    @Property(name="state")
    @JsonIgnore
    public Optional<SynchronizationScheduleState> getState() {
        return Optional.ofNullable(state);
    }

    public SynchronizationSchedule withState(SynchronizationScheduleState state) {
        SynchronizationSchedule _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSchedule");
        _x.state = state;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime expiration;
        private Duration interval;
        private SynchronizationScheduleState state;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder expiration(OffsetDateTime expiration) {
            this.expiration = expiration;
            this.changedFields = changedFields.add("expiration");
            return this;
        }

        public Builder interval(Duration interval) {
            this.interval = interval;
            this.changedFields = changedFields.add("interval");
            return this;
        }

        public Builder state(SynchronizationScheduleState state) {
            this.state = state;
            this.changedFields = changedFields.add("state");
            return this;
        }

        public SynchronizationSchedule build() {
            SynchronizationSchedule _x = new SynchronizationSchedule();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.synchronizationSchedule";
            _x.expiration = expiration;
            _x.interval = interval;
            _x.state = state;
            return _x;
        }
    }

    private SynchronizationSchedule _copy() {
        SynchronizationSchedule _x = new SynchronizationSchedule();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.expiration = expiration;
        _x.interval = interval;
        _x.state = state;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SynchronizationSchedule[");
        b.append("expiration=");
        b.append(this.expiration);
        b.append(", ");
        b.append("interval=");
        b.append(this.interval);
        b.append(", ");
        b.append("state=");
        b.append(this.state);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/SynchronizationSchedule.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.Duration;
import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.enums.SynchronizationScheduleState;

@JsonPropertyOrder({
    "@odata.type", 
    "expiration", 
    "interval", 
    "state"})
@JsonInclude(Include.NON_NULL)
public class SynchronizationSchedule implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("expiration")
    protected OffsetDateTime expiration;

    @JsonProperty("interval")
    protected Duration interval;

    @JsonProperty("state")
    protected SynchronizationScheduleState state;

    protected SynchronizationSchedule() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.synchronizationSchedule";
    }

    @Property(name="expiration")
    @JsonIgnore
    public Optional<OffsetDateTime> getExpiration() {
        return Optional.ofNullable(expiration);
    }

    public SynchronizationSchedule withExpiration(OffsetDateTime expiration) {
        SynchronizationSchedule _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSchedule");
        _x.expiration = expiration;
        return _x;
    }

    @Property(name="interval")
    @JsonIgnore
    public Optional<Duration> getInterval() {
        return Optional.ofNullable(interval);
    }

    public SynchronizationSchedule withInterval(Duration interval) {
        SynchronizationSchedule _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSchedule");
        _x.interval = interval;
        return _x;
    }

    @Property(name="state")
    @JsonIgnore
    public Optional<SynchronizationScheduleState> getState() {
        return Optional.ofNullable(state);
    }

    public SynchronizationSchedule withState(SynchronizationScheduleState state) {
        SynchronizationSchedule _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.synchronizationSchedule");
        _x.state = state;
        return _x;
    }

    public SynchronizationSchedule withUnmappedField(String name, Object value) {
        SynchronizationSchedule _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime expiration;
        private Duration interval;
        private SynchronizationScheduleState state;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder expiration(OffsetDateTime expiration) {
            this.expiration = expiration;
            this.changedFields = changedFields.add("expiration");
            return this;
        }

        public Builder interval(Duration interval) {
            this.interval = interval;
            this.changedFields = changedFields.add("interval");
            return this;
        }

        public Builder state(SynchronizationScheduleState state) {
            this.state = state;
            this.changedFields = changedFields.add("state");
            return this;
        }

        public SynchronizationSchedule build() {
            SynchronizationSchedule _x = new SynchronizationSchedule();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.synchronizationSchedule";
            _x.expiration = expiration;
            _x.interval = interval;
            _x.state = state;
            return _x;
        }
    }

    private SynchronizationSchedule _copy() {
        SynchronizationSchedule _x = new SynchronizationSchedule();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.expiration = expiration;
        _x.interval = interval;
        _x.state = state;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SynchronizationSchedule[");
        b.append("expiration=");
        b.append(this.expiration);
        b.append(", ");
        b.append("interval=");
        b.append(this.interval);
        b.append(", ");
        b.append("state=");
        b.append(this.state);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
